<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://docular.net
 * @since             1.0.0
 * @package           Docular
 *
 * @wordpress-plugin
 * Plugin Name:       Docular - Privacy Policies, Terms & Conditions
 * Plugin URI:        https://docular.net/pages/docular-wordpress-plugin/
 * Description:       Add GDPR-friendly privacy policies and terms and conditions to your website, using the FREE Docular document generator.
 * Version:           1.1.0
 * Author:            Docular
 * Author URI:        https://docular.net/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       docular
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'DOCULAR_VERSION', '1.1.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-docular-activator.php
 */
function activate_docular() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-docular-activator.php';
	Docular_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-docular-deactivator.php
 */
function deactivate_docular() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-docular-deactivator.php';
	Docular_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_docular' );
register_deactivation_hook( __FILE__, 'deactivate_docular' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-docular.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_docular() {

	$plugin = new Docular();
	$plugin->run();

}
run_docular();
