<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://docular.net
 * @since      1.0.0
 *
 * @package    Docular
 * @subpackage Docular/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Docular
 * @subpackage Docular/public
 * @author     Your Name <email@example.com>
 */
class Docular_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $docular    The ID of this plugin.
	 */
	private $docular;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * THIS VARIABLE SHOULD BE AN EMPTY ARRAY unless the testing server is being used in which case
	 * as it doesn't have an SSL certificate in which case use:
	 * private $SSL_context_option = array("ssl"=>array("verify_peer"=>false,"verify_peer_name"=>false,),);
	 *
	 * @since    1.0.0
	 * @param      string    $docular       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */

	 private $SSL_context_option;  

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $docular       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */

	public function __construct( $docular, $version ) {

		$this->docular = $docular;
		$this->version = $version;
		$this->api_uri = "https://docular.net/api/v2/"; // must contain trailing slash!
		$this->SSL_context_option = array();  

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	
	public function enqueue_styles() {
		wp_enqueue_style( $this->docular, plugin_dir_url( __FILE__ ) . 'css/docular-public.css', array(), $this->version, 'all' );
	}
	
	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	
	public function enqueue_scripts() {
		wp_enqueue_script( $this->docular, plugin_dir_url( __FILE__ ) . 'js/docular-public.js', array( 'jquery' ), $this->version, false );
	}
	





	/**
	 * Callback action for WP Shortcode that populate the page with the HTML if it contains a valid docular shortcode
	 *
	 * @since    1.0.0
	 * @param      string    $atts       Attribues in the shortcode
	 */
	
	function docular_shortcode_action($atts) {

		$attributes = shortcode_atts( array(
			'documentkey' => null,
			'title' => 'true',
			'css' => '1',
		), $atts );

		if(!isset($attributes['documentkey']) || strlen($attributes['documentkey']) != 16) {
			return "<!-- Invalid Documentkey -->";
		}
		elseif($docular = json_decode(get_option( 'docular-'.$attributes['documentkey']), true)) {	

			if(isset($docular['html'])) {
				if($attributes['title'] == 'false') {
					$html = preg_replace("/^\<h1[^\>]*\>(.*)\<\/h1\>/iU", "", $docular['html']);
					return $html;
				}
				else return $docular['html'];
			}
			else {
				return "<!-- No HTML found -->";
			}	

		}
		else {
			return "<!-- Document with Documentkey " . $attributes['documentkey'] . " not found -->";
		}
	}
	
	
	

 
	/**
	 * Callback action for wp_head that adds CSS to the page head if content contains a valid docular shortcode
	 *
	 * @since    1.0.0
	 * 
	 */

	function docular_modify_head_action() {
		global $post, $wpdb;

		if(isset($post->post_content)) {
			$pattern = get_shortcode_regex();
			if(preg_match_all( '/'. $pattern .'/s', $post->post_content, $matches )) {
	
				foreach($matches[0] as $code) {
	
	
					if(strpos($code, "[docular ") !== false) {
					
					
						if(preg_match("/documentkey\=\"([a-z0-9]{16})\"/i", $code, $documentkeyfind)) {
							$documentkey = $documentkeyfind[1];
							if($docular = json_decode(get_option( 'docular-'.$documentkey), true)) {
								echo("<style>" . PHP_EOL . $docular['css'] . "</style>" . PHP_EOL);	
							}	
						}
					}
				}		
			}
		}
	}



}
